name

# XMLRésuméLibrary: User Guide

month | Element Reference | node

## Name

name — A person's name

## Synopsis

### Content Model

    (title?,firstname,middlenames?,surname,suffix?)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `name` element contains a person's name.

### Parents

`name` may be contained in these elements: `copyright`, `header`, `referee`

### Attributes

`id`

  A string used to uniquely identify a name. The name may then be referred to by this identifier.

## Examples

    <name>
      <title>Mr.</title>
      <firstname>John</firstname>
      <middlenames>Q.</middlenames>
      <surname>Doe</surname>
    </name>

    <name>
      <firstname>Joe</firstname>
      <middlenames>Sam George Bob</middlenames>
      <surname>Flamboyzo</surname>
      <suffix>Jr.</suffix>
    </name>

    <name>
      <firstname>King</firstname>
      <surname>Louis</surname>
      <suffix>VIII</suffix>
    </name>

month | Element Reference | node